% Description:
% ------------
% A simple example to demonstrate the HFSS-MATLAB-API. This script will
% open and run an HFSS project "tmpDipole.hfss" existing in the folder of
% ../hfssapi/hfssPrjForTest.


clc;clear all;close all;

% add paths to the required m-files of  HFSS-MATLAB-API. This *.m file is 
% in the folder of ../hfssapi/examples, the hfssapi folder is where
% HFSS-MATLAB-API exists.
addpath('../3dmodeler/');
addpath('../general/');
addpath('../analysis/');
addpath('../boundary/');

PrjFile = '..\hfssPrjForTest\tmpDipole.hfss';
% Temporary Files. These files can be deleted after the optimization
% is complete. We have to specify the complete path for all of them.
hfssTempPath = 'E:\tmpHFSS';

tmpScriptFile = [hfssTempPath '\' 'tmpDipole_Open_Run_Exit.vbs'];

% HFSS Executable Path.
hfssExePath = 'C:\"Program Files"\Ansoft\HFSS14.0\Win64\hfss.exe';

% Plot Colors.
pltCols = ['b', 'r', 'k', 'g', 'm', 'c', 'y'];
nCols = length(pltCols);

% Simulation Parameters.
fLow = 100e6;
fHigh = 200e6;
nPoints = 201;

% Target frequency and maximum iterate times
fGoal = 150e6;
maxIters = 15;
L = 0.5;
Accuracy = 0.01;
hasConverged = false;

for iIters = 1 : maxIters
    disp('Creating the Script File ...');

    % Create a new temporary HFSS script file.
    fid = fopen(tmpScriptFile, 'wt');

    % Open the existing PrjFile HFSS Project.
    hfssOpenProject(fid,PrjFile);

    % Set parameter L.
    LinString = [num2str(L) 'meter'];
    fprintf(fid, ' oProject.ChangeProperty Array("NAME:AllTabs", Array("NAME:ProjectVariableTab", Array("NAME:PropServers",  _\n');
    fprintf(fid, ' "ProjectVariables"), Array("NAME:ChangedProps", Array("NAME:$L", "Value:=", "%s"))))\n',LinString);
  
    % Run the Project. The project involves only one design.  
    fprintf(fid, ' Set oDesign = oProject.GetActiveDesign()\n');
    fprintf(fid, ' oDesign.AnalyzeAll\n');

    % Creat the report -- S11
    fprintf(fid, ' Set oModule = oDesign.GetModule("ReportSetup")\n');
    fprintf(fid, ' oModule.DeleteAllReports\n');  %Just to show the following reports.
    fprintf(fid, ' oModule.CreateReport "S11", "Modal Solution Data", "Rectangular Plot", _\n');
    fprintf(fid, ' "Setup150MHz : Sweep100to200MHz", Array("Domain:=", "Sweep"), Array("Freq:=", Array("All"), _\n');
    fprintf(fid, ' "$L:=", Array("Nominal")), Array("X Component:=", "Freq", _\n');
    fprintf(fid, ' "Y Component:=", Array("dB(S(LumpedPort,LumpedPort))")), Array() \n');

    % Creat the report -- 3D Pattern.
    fprintf(fid, ' oModule.CreateReport "3D Pattern", "Far Fields", "3D Polar Plot", _\n');
    fprintf(fid, ' "Setup150MHz : LastAdaptive", Array("Context:=", "Infinite Sphere1"), Array("Phi:=", Array("All"), _\n');
    fprintf(fid, ' "Theta:=", Array("All"), "Freq:=", Array("0.15GHz")), Array("Phi Component:=", _\n');
    fprintf(fid, ' "Phi", "Theta Component:=", "Theta", "Mag Component:=", Array("dB(GainTotal)")), Array() \n');

    % Export S11 data.
    fprintf(fid, ' Set oModule = oDesign.GetModule("ReportSetup") \n');
    fprintf(fid, ' oModule.ExportToFile "S11", "tmpDataOfDipole.csv" \n');

    % Save the project.
    hfssSaveProject(fid, PrjFile);
    
    % Close the project.
    hfssCloseActiveProject(fid);

    % Close the HFSS Script File.
    fclose(fid);

    % Execute the Script by starting HFSS.
    disp('Solving using HFSS ..');
    IconMode = true;
    RunAndExit = true; 
    hfssExecuteScript(hfssExePath, tmpScriptFile, IconMode, RunAndExit);

    % Read S11 data.
    tmpFid = fopen('tmpDataOfDipole.csv', 'r');
%     fseek(tmpFid,46,'bof');  % length of'"Freq [MHz]","dB(S(LumpedPort,LumpedPort)) []"'
    tmpStr = fgetl(tmpFid);
    tmpData = fscanf(tmpFid, '%f,%f\n', [2 inf]);
    fclose(tmpFid);

 	% The data items are in the f, S, Z variables now. 
	% Plot the data.
	disp('Solution Completed. Plotting Results for this Iteration ...');
	figure(1);
	hold on;
    f = tmpData(1,:);
    S = tmpData(2,:);
	plot(f, S, pltCols(mod(iIters, nCols) + 1)); 
    hold on;
	xlabel('Frequency (MHz) ->');
	ylabel('S_{11} (dB) ->');
	axis([fLow/1e6, fHigh/1e6, -20, 0]);

    [Smin, iMin] = min(S);
    fActual = tmpData(1,iMin);
    if (abs(fGoal/1e6 - fActual)/(fGoal/1e6) < Accuracy)
        disp('Required Accuracy is met !!');
%        disp(sprintf('Optimized Antenna Length is %.2f meter.', L));
        hasConverged = true;
        break;
    end
	% Adjust the antenna length in accordance with the discrepancy between
	% the estimated and desired resonance frequency.
	L = L*fActual/(fGoal/1e6);
	% Loop all over again ...
	disp('Required accuracy not yet met ...');
	disp(sprintf('The new estimate for the dipole length is %.2f meter', L));
end

% remove all the added paths.
rmpath('../3dmodeler/');
rmpath('../general/');
rmpath('../analysis/');
rmpath('../boundary/');
